<?php
/**
* @package Custom Author Box
*/
/*
Plugin Name: Custom Author Box
Plugin URI: https://facebook.com/authorbox
Description: Custom Author Box Widget adds custom widget to widget area where you can customize and add the list of authors on site with customized avatar style to sidebar.
Version: 0.1
Author: Mehran Khan
Author URI: https://facebook.com/mehranumr
License: GPLv2 or later
Text Domain: Custom Author Box
*/
/*
*===============================================================
*							Custom Author Box Widget v1.0
*===============================================================
*/
/* initialization
* Sets up and add Custom Author Box widget
*/
add_image_size( 'ab_author', 80, 80 );
add_action( 'widgets_init', function()
{
	register_widget( 'ab_widget' );
});
/** 
* Class ab_widget
* ab_widget extends WP_Widget class
*/
class ab_widget extends WP_Widget
{
/**
* Sets up the widgets name etc
*/
public function __construct() 
{
	$widget_ops = array( 
		'classname' => 'ab_widget',
		'description' => 'Custom Author Box is Awesome ! But Author of this is still Jobless !',
		);
	parent::__construct( 'ab_widget', 'Custom Author Box', $widget_ops );

}
/**
* Print the Custom Author Box widget on the front end.
*
* @uses ab_display_posts
*
* @param array $args
*
* @param array $instance The widget options
* @param $ab_author_count,$ab_ch_avatar,$ab_ch_name
*
* Prints Custom Author Box Widget HTML to Front-End.
* @since 0.1
*/
public function widget( $args, $instance ) 
{
// outputs the content of the widget
	$ab_title 			= ! empty( $instance['ab_title'] ) 			? 	$instance['ab_title'] : esc_html__( 'New title', 'text_domain' );
	$ab_author_count 	= ! empty( $instance['ab_author_count'] ) 	? 	$instance['ab_author_count'] :'';
	$ab_ch_avatar		= ! empty( $instance[ 'ab_ch_avatar' ] ) 	? 	$instance[ 'ab_ch_avatar' ]: '';
	$ab_ch_name			= ! empty( $instance[ 'ab_ch_name' ] ) 		? 	$instance[ 'ab_ch_name' ]: '';
	$ab_avatar_style 	= ! empty( $instance['ab_avatar_style'] )	?	$instance['ab_avatar_style']:'square';
	$ab_avatar_size 	= ! empty( $instance['ab_avatar_size'] ) 	? 	$instance['ab_avatar_size']:'';
	//calling style with some args
	$this->ab_styles($instance);
	?>
	<aside id="ab-widget-area" class="widget">
		<h2 class="widget-title"><?php echo $ab_title; ?></h2>	
		<?php 
		$this->ab_display_posts($ab_author_count,$ab_ch_avatar,$ab_ch_name); 
		?>
	</aside>
	<?php
}
/**
* Outputs the options form on admin
*
* @param array $instance The widget options
*
* Prints Custom Author Box Widget to Widget Area on Admin Side.
*
* Prints All HTML
*/
public function form( $instance ) 
{
// outputs the options form on admin
	$ab_title 			= ! empty( $instance['ab_title'] ) 			? $instance['ab_title'] : esc_html__( 'New title', 'text_domain' );
	$ab_author_count 	= ! empty( $instance['ab_author_count'] ) 	? $instance['ab_author_count'] :'';
	$ab_ch_avatar		= ! empty( $instance[ 'ab_ch_avatar' ] ) 	? $instance[ 'ab_ch_avatar' ]: '';
	$ab_ch_name			= ! empty( $instance[ 'ab_ch_name' ] ) 		? $instance[ 'ab_ch_name' ]: '';
	$ab_avatar_style 	= ! empty( $instance['ab_avatar_style'] ) 	? $instance['ab_avatar_style']:'square';
	$ab_avatar_size 	= ! empty( $instance['ab_avatar_size'] ) 	? $instance['ab_avatar_size'] :'';
	?>
	<p>
		<label for="<?php echo esc_attr( $this->get_field_id( 'ab_title' ) ); ?>">Title</label> 
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'ab_title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'ab_title' ) ); ?>" type="text" value="<?php echo esc_attr( $ab_title ); ?>"><br><br>
		<label for="<?php echo esc_attr( $this->get_field_id( 'ab_author_count' ) ); ?>">How many Authors?</label>
		<input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'ab_author_count' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'ab_author_count' ) ); ?>" type="number" step="1" min="1" value="<?php echo esc_attr( $ab_author_count ); ?>">
		<br><br>
		<input class="checkbox" type="checkbox" <?php checked( $instance[ 'ab_ch_avatar' ], 'on' ); ?> id="<?php echo $this->get_field_id( 'ab_ch_avatar' ); ?>" name="<?php echo $this->get_field_name( 'ab_ch_avatar' ); ?>" /> 
		<label for="ab-widget">Show Avatar</label><br><br>
		<input class="checkbox" type="checkbox" <?php checked( $instance[ 'ab_ch_name' ], 'on' ); ?> id="<?php echo $this->get_field_id( 'ab_ch_name' ); ?>" name="<?php echo $this->get_field_name( 'ab_ch_name' ); ?>" /> 
		<label for="ab-widget">Show Display Name</label><br><br>
		<label for="ab-widget">Avatar Mask</label><br>
		<select name="<?php echo $this->get_field_name( 'ab_avatar_style'); ?>" id="<?php echo $this->get_field_id( 'ab_avatar_style' ); ?>" class="widefat">
			<option class="level-0" selected value="<?php echo esc_attr( $ab_avatar_style );?>"><?php echo esc_attr( $ab_avatar_style ); ?></option>
			<option class="level-0" value="Circle">Circle</option>
			<option class="level-0" value="Diamond">Diamond</option>
			<option class="level-0" value="Heart">Heart</option>
			<option class="level-0" value="Hexagon">Hexagon</option>
			<option class="level-0" value="Octagon">Octagon</option>
			<option class="level-0" value="Oval">Oval</option>
			<option class="level-0" value="Pentagon">Pentagon</option>
			<option class="level-0" value="Rounded-Corner">Rounded-Corner</option>
			<option class="level-0" value="Square">Square</option>
			<option class="level-0" value="Star">Star</option>
			<option class="level-0" value="Triangle">Triangle</option>
		</select><br><br>
		<label for="<?php echo esc_attr( $this->get_field_id( 'ab_avatar_size' ) ); ?>">Avatar Size</label>
		<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'ab_avatar_size' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'ab_avatar_size' ) ); ?>" type="number" step="1" min="1" placeholder="80" value="<?php echo esc_attr( $ab_avatar_size ); ?>"><br><br>
	</p>
	<?php
}
/**
* Processing widget options on save
* Sanitize widget form values as they are saved.
*
* @param $new_instance, $old_instance, $instance
*
*/
public function update( $new_instance, $old_instance ) 
{
	$instance = array();
	$instance['ab_title'] 			= 	( ! empty( $new_instance['ab_title'] ) ) ? strip_tags( $new_instance['ab_title'] ) : '';
	$instance['ab_author_count'] 	= 	( ! empty( $new_instance['ab_author_count'] ) ) ? strip_tags( $new_instance['ab_author_count'] ) : '';
	$instance['ab_ch_avatar'] 		= 	( ! empty( $new_instance['ab_ch_avatar'] ) ) ? strip_tags( $new_instance['ab_ch_avatar'] ) : '';
	$instance['ab_ch_name'] 		= 	( ! empty( $new_instance['ab_ch_name'] ) ) ? strip_tags( $new_instance['ab_ch_name'] ) : '';
	$instance['ab_avatar_style'] 	= 	( ! empty( $new_instance['ab_avatar_style'] ) ) ? strip_tags( $new_instance['ab_avatar_style'] ) : '';
	$instance['ab_avatar_size'] 	= 	( ! empty( $new_instance['ab_avatar_size'] ) ) ? strip_tags( $new_instance['ab_avatar_size'] ) : '';
	
	return $instance;
}
/**
* ab_display_posts()
*
* @param $ab_author_count,$ab_ch_avatar,$ab_ch_name
* @param $new_instance, $old_instance, $instance
* Prints Custom Author Box information into ab-widget-area on Front-End.
* 
* @uses get_avatar()
* @uses get_users()
*
*/
function ab_display_posts( $ab_author_count , $ab_ch_avatar , $ab_ch_name )
{
	//echo $ab_ch_name;
	
	rewind_posts();
	$avatar_count=0;
	$allUsers = get_users('orderby=post_count&order=DESC');
	$users = array();

	// Remove subscribers from the list as they won't write any articles
	
	foreach($allUsers as $currentUser)
	{
		$avatar_count ++;
		if ($avatar_count<= $ab_author_count)
		{
			if(!in_array( 'subscriber', $currentUser->roles ))
			{
				$users[] = $currentUser;
			}
		}
	}
	?>
	<?php
	
	foreach( $users as $user )
	{
		//print_r($user);
		echo "<a href=".get_author_posts_url($user->ID).">";
		echo '<div class="ab-avatar">';
		echo ! empty($ab_ch_avatar) ? get_avatar( $user->user_email, '50' ):'';
		echo ! empty($ab_ch_name)? "<span>".substr($user->display_name,0,8). "</span>": '';
		echo '</div>';
		echo "</a>";
	}
	?>
	<?php
//end for each
}
/**
* ab_styles()
* @param $instance
* Add Css Tags to Generate Custom Style.
*/
function ab_styles($instance) 
{
	//calling styling params
	$ab_avatar_style= (! empty($instance['ab_avatar_style'] )) ? $instance['ab_avatar_style'] : 'Square';
	$ab_avatar_size = (! empty( $instance['ab_avatar_size'] )) ? $instance['ab_avatar_size']  : '80';
	?>
	<style>
		#ab-widget-area
		{
			display: inline-block;
			min-width: 100%;
		}
		.ab-avatar
		{
			min-width:<?php echo $ab_avatar_size;?>px;
			max-width:<?php echo $ab_avatar_size;?>px;
			float: left;
			margin: 2px;
		}
		.site .avatar 
		{
			border-radius: 0px;
		}
		.ab-avatar span
		{
			background: transparent;
			text-align: center;
			display: inline-block;
			width: 100%;
			font-size:x-small;
			overflow: hidden;
		}
		.ab-avatar img 
		{
			width: 100%;
			max-height:<?php echo $ab_avatar_size;?>px;
			-webkit-mask-position: 0 0;
			-webkit-mask-image: url(<?php echo plugins_url()."/author-box/inc/". $ab_avatar_style.".png";?>);
			-webkit-mask-size: <?php echo $ab_avatar_size;?>px <?php echo $ab_avatar_size;?>px;
			mask-image: url(<?php echo plugins_url()."/author-box/inc/".$ab_avatar_style.".png";?>);
			margin: 0px;
			float: left;
			transition:all 0.3s ease;
		}
		.ab-avatar img:hover 
		{
			-webkit-transform: scale(0.9);
			-ms-transform: scale(0.9);
			transform: scale(0.9);
			transition:all 0.3s ease;
		}
	</style>
	<?php
}
}
?>